/*
 * Copyright (c) 2015 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef __APP_MANAGER_UTILS_H__
#define __APP_MANAGER_UTILS_H__

#include <Elementary.h>
#include <stdbool.h>
#include <app_manager.h>

/**
 * @brief Get all visible application handles
 * @return      List of application handles
 */
Eina_List *get_all_apps(void);

/**
 * @brief Destroy application information handles
 * @param[in]   app_list    List of application handles
   @return      true if success, otherwise false
 */
bool destroy_all_apps_list(Eina_List *app_list);

/**
 * @brief Get label for application
 * @param[in]   app_info    Application information object
 * @param[out]  label       Application label
 * @return      true if success, otherwise false
 */
bool get_app_label(app_info_h *app_info, char **label);

/**
 * @brief Get icon for application
 * @param[in]   app_info    Application information object
 * @param[out]  path        Application icon path
 * @return      true if success, otherwise false
 */
bool get_app_icon(app_info_h *app_info, char **path);

/**
 * @brief Get label for application
 * @param[in]   app_info    Application information object
 * @param[out]  package     Application package
 * @return      true if success, otherwise false
 */
bool get_app_package(app_info_h *app_info, char **package);

#endif /* __APP_MANAGER_UTILS_H__ */
