/*
 * Copyright (c) 2015 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <app.h>

#include "main-app.h"
#include "model/app-manager-utils.h"
#include "utils/logger.h"
#include "view/main-view.h"

#define BASE_DISPLAY_SCALE 1.8

/* app event callbacks */
static bool __on_create_cb(void *user_data);
static void __on_terminate_cb(void *user_data);
static void __on_pause_cb(void *user_data);
static void __on_resume_cb(void *user_data);
static void __on_control_cb(app_control_h app_control, void *user_data);

app_data *create_app(void)
{
	elm_app_base_scale_set(BASE_DISPLAY_SCALE);

	return calloc(1, sizeof(app_data));
}

void destroy_app(app_data *app)
{
	free(app);
}

int run_app(app_data *app, int argc, char **argv)
{
	ui_app_lifecycle_callback_s cbs = {
		.create = __on_create_cb,
		.terminate = __on_terminate_cb,
		.pause = __on_pause_cb,
		.resume = __on_resume_cb,
		.app_control = __on_control_cb,
	};

	return ui_app_main(argc, argv, &cbs, app);
}

static bool __on_create_cb(void *user_data)
{
    app_data *ad = user_data;
    RETVM_IF(!ad, false, "ad is NULL");

    elm_app_base_scale_set(1.8);

    ad->win = create_win();
    RETVM_IF(!ad->win, false, "win is NULL");

    Evas_Object *content = add_main_view(ad, ad->win->conform);
    RETVM_IF(!content, false, "content is NULL");

    set_win_content(ad->win, content);

    return true;
}

static void __on_terminate_cb(void *user_data)
{
    app_data *app = user_data;
    RETM_IF(!app, "app is NULL");

    main_view_data *main_data = (main_view_data *)app->main_view_data;
    destroy_all_apps_list(main_data->app_list);

    free(app->main_view_data);
    app->main_view_data = NULL;

    destroy_win(app->win);
    app->win = NULL;
}

static void __on_pause_cb(void *user_data)
{
	/* Take necessary actions when application becomes invisible. */
}

static void __on_resume_cb(void *user_data)
{
	/* Take necessary actions when application becomes visible. */
}

static void __on_control_cb(app_control_h app_control, void *user_data)
{
	/* Handle the launch request. */
}

