/*
 * Copyright (c) 2015 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <Elementary.h>

#include "model/app-manager-utils.h"
#include "utils/logger.h"
#include "view/gengrid-view.h"
#include "view/popup-view.h"

/* gengrid item size */
#define GENGRID_ITEM_WIDTH 200
#define GENGRID_ITEM_HEIGHT 200

/* gengrid item class */
static Elm_Gengrid_Item_Class *itc = NULL;

static Evas_Object *__get_grid_content(void *data,
										  Evas_Object *obj,
										  const char *part);
static void __initialize_gengrid_item_class(void);
static void __gengrid_item_selected(void *data,
										Evas_Object *obj,
										void *event_info);

Evas_Object *create_gengrid(Evas_Object *parent)
{
    RETVM_IF(!parent, NULL, "Passed NULL parent data");

    if (!itc)
        __initialize_gengrid_item_class();

    Evas_Object *gengrid = elm_gengrid_add(parent);
    elm_gengrid_item_size_set(gengrid,
									ELM_SCALE_SIZE(GENGRID_ITEM_WIDTH),
									ELM_SCALE_SIZE(GENGRID_ITEM_HEIGHT));
    elm_gengrid_reorder_mode_set(gengrid, EINA_TRUE);
    elm_gengrid_horizontal_set(gengrid, EINA_TRUE);

    evas_object_size_hint_weight_set(gengrid,
											EVAS_HINT_EXPAND,
											EVAS_HINT_EXPAND);
    evas_object_size_hint_align_set(gengrid, EVAS_HINT_FILL, EVAS_HINT_FILL);
    return gengrid;
}

Elm_Object_Item *append_item(Evas_Object *gengrid, app_info_h *app_info)
{
    RETVM_IF(!gengrid || !app_info, NULL, "Passed NULL input data");

    if (!itc)
        __initialize_gengrid_item_class();

    Elm_Object_Item *item = elm_gengrid_item_append(gengrid,
														itc,
														app_info,
														__gengrid_item_selected,
														app_info);
    return item;
}

static Evas_Object *__get_grid_content(void *data,
										  Evas_Object *obj,
										  const char *part)
{
    if (!strcmp(part, "elm.swallow.icon")) {
        Evas_Object *image = elm_image_add(obj);
        app_info_h *app_info = (app_info_h *)data;
        char *icon;
        app_info_get_icon(*app_info, &icon);
        if (!elm_image_file_set(image, icon, NULL)) {
            evas_object_del(image);
            Evas_Object *bg = elm_bg_add(obj);
            elm_bg_color_set(bg, 255, 255, 0);
            return bg;
        }
        return image;
    }
    return NULL;
}

static void __initialize_gengrid_item_class(void)
{
    itc = elm_gengrid_item_class_new();
    itc->item_style = "default";
    itc->func.text_get = NULL;
    itc->func.content_get = __get_grid_content;
    itc->func.state_get = NULL;
    itc->func.del = NULL;
}

static void __gengrid_item_selected(void *data,
										Evas_Object *obj,
										void *event_info)
{
    create_popup(obj, (app_info_h *)data);
}
