/*
 * Copyright (c) 2015 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <Elementary.h>
#include <efl_extension.h>

#include "main-app.h"
#include "model/app-manager-utils.h"
#include "utils/logger.h"
#include "view/gengrid-view.h"
#include "view/main-view.h"

static void __main_view_hardware_buttons_cb(void *data,
												 Evas_Object *type,
												 void *event);

Evas_Object *add_main_view(app_data *app, Evas_Object *parent)
{
    RETVM_IF(!app || !parent, NULL, "Passed NULL input data");

    main_view_data *data = calloc(1, sizeof(main_view_data));
    data->win = app->win;
    app->main_view_data = data;

    data->gengrid = create_gengrid(data->win->win);

    data->app_list = get_all_apps();
    Eina_List *it = NULL;
    app_info_h *app_info = NULL;
    EINA_LIST_FOREACH(data->app_list, it, app_info)
    {
        append_item(data->gengrid, app_info);
    }

    eext_object_event_callback_add(data->gengrid, EEXT_CALLBACK_BACK,
										__main_view_hardware_buttons_cb,
										data);

    return data->gengrid;
}

static void __main_view_hardware_buttons_cb(void *data,
												  Evas_Object *type,
												  void *event)
{
    RETM_IF(!data, "input data == NULL");
    main_view_data *ad = data;

    elm_win_lower(ad->win->win);
}
