/*
 * Copyright (c) 2015 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <Elementary.h>

#include "model/app-manager-utils.h"
#include "utils/logger.h"
#include "view/popup-view.h"

#define BUF_SIZE 1024
#define POPUP_TIMEOUT 5.0

static void __block_clicked(void *data, Evas_Object *obj, void *event_info);

void create_popup(Evas_Object *parent, app_info_h *app_info)
{
    RETM_IF(!parent || !app_info, "Passed NULL input data");

    Evas_Object *popup = elm_popup_add(parent);

    char *label;
    char *icon;
    char *package;
    get_app_label(app_info, &label);
    get_app_icon(app_info, &icon);
    get_app_package(app_info, &package);

    elm_object_part_text_set(popup, "title,text", label);
    char info[BUF_SIZE];
    snprintf(info, BUF_SIZE, "Icon path:<br>%s<br><br>Package:<br>%s",
				icon,
				package);

    elm_object_part_text_set(popup, "default", info);

    free(label);
    free(icon);
    free(package);

    evas_object_smart_callback_add(popup, "block,clicked",
										__block_clicked,
										NULL);
    elm_popup_timeout_set(popup, POPUP_TIMEOUT);

    evas_object_show(popup);
}

static void __block_clicked(void *data, Evas_Object *obj, void *event_info)
{
    evas_object_del(obj);
}
